==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/lsfunctions/LSSendReceiveSession.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const LSSendReceiveSession_cxx_Version = 
"$Id: LSSendReceiveSession.cxx,v 1.3 2000/11/07 21:06:42 surendra Exp $";

#include <strstream.h>
#include "LSSendReceiveSession.hxx"
#include "TRIPOpenMsg.hxx"
#include "cpLog.h"

void 
LSSendReceiveSession::dump(ostream& os) const
{
    os << "***LSSendReceive***" << endl;
    LSPeerSession::dump(os);
}

void
LSSendReceiveSession::sendOpen() throw (VNetworkException&)
{
    assert(_connection.isLive());
    ///Send OPEN MSG
    cpLog(LOG_DEBUG, "Sending OPEN Msg.");
    TRIPOpenMsg msg(_parentItad, _tripId.getId(), 4*60);
    Sptr<TRIPCapabilityInfo>  cInfo = new TRIPCapabilityInfo();

    Sptr<TRIPTransCapability> cap = new TRIPTransCapability(TRIP_TRANS_SND_RCV); 
    cInfo->addCapability(cap);

    Sptr<TRIPRouteCapability> rCap = new TRIPRouteCapability();
    Sptr<TRIPRouteHdr> rHdr1 = new TRIPRouteHdr(TRIP_ADDR_POTS, TRIP_APP_PROTO_SIP);
    rCap->addRouteCapability(rHdr1);
    Sptr<TRIPRouteHdr> rHdr2 = new TRIPRouteHdr(TRIP_ADDR_POTS, TRIP_APP_PROTO_H323_Q921);
    rCap->addRouteCapability(rHdr2);
    Sptr<TRIPRouteHdr> rHdr3 = new TRIPRouteHdr(TRIP_ADDR_POTS, TRIP_APP_PROTO_H323_ANNEX_G);
    rCap->addRouteCapability(rHdr3);
    cInfo->addCapability(rCap);

    msg.addParameter(cInfo);
    char buf[4096];
    strstream oStr(buf, 4096);
    oStr << msg << endl << ends;
    cpLog(LOG_DEBUG, "%s", oStr.str());
    msg.writeData(_connection.getConnId());
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/lsfunctions/LSSendReceiveSession.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const LSSendReceiveSession_cxx_Version = 
"$Id: LSSendReceiveSession.cxx,v 1.7 2001/02/02 23:58:35 sprajpat Exp $";

#include <strstream.h>
#include "LSSendReceiveSession.hxx"
#include "TRIPOpenMsg.hxx"
#include "cpLog.h"

LSSendReceiveSession::LSSendReceiveSession(u_int16_t itad,
                        const TRIPId& tripId,const NetworkAddress& lsAddress)
    : LSPeerSession(itad, tripId, lsAddress)
{
    cpLog(LOG_DEBUG, "Creating Send/Receive peer session");
    createOpenMsg();
};

LSSendReceiveSession::LSSendReceiveSession(u_int16_t itad, u_int16_t pItad,
                      const TRIPId& tripId, const TRIPId& pTripId,
                      const Connection& conn)
    : LSPeerSession(itad, pItad, tripId, pTripId, conn)
{
    cpLog(LOG_DEBUG, "Creating Send/Receive peer session");
    createOpenMsg();
};

void 
LSSendReceiveSession::dump(ostream& os) const
{
    os << "***LSSendReceive***" << endl;
    LSPeerSession::dump(os);
}
